@@ -4,3 +4,6 @@ pub use object::ObjectAccessExt;
 
 mod reference;
 pub use reference::ReferenceAccessExt;
+
+mod config;
+pub use config::ConfigAccessExt;
