@@ -2,7 +2,7 @@ use git_object::{bstr::BStr, TreeRefIter};
 
 use crate::{
     easy,
-    easy::{object::find, TreeRef},
+    easy::{ext::ObjectAccessExt, object::find, TreeRef},
 };
 
 impl<'repo, A> TreeRef<'repo, A>
@@ -30,7 +30,7 @@ where
                         let access = self.access;
                         drop(entry);
                         drop(self);
-                        self = match crate::easy::ext::object::find_object(access, next_id)?.try_into_tree() {
+                        self = match access.find_object(next_id)?.try_into_tree() {
                             Ok(tree) => tree,
                             Err(_) => return Ok(None),
                         };
